United States Court of Appeals, Eleventh Circuit
Description: The United States Court of Appeals for the Eleventh Circuit
Keywords: court of appeals, U.S. Courts, opinions, Eleventh Circuit, 11th Circuit, United States Court of Appeals

Published Opinions Listed by Case Name (Newest First)

Listing 1 - 20 of 8710 results.

Page: 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 >>

Case Name | Appeal Case # | District Court Docket # | Type | Date of Issuance
--- | --- | --- | --- | ---
Entela Ruga v. U.S. Attorney General | 13-14377 | A095-969-131 | NEW | 07-02-2014
Manuel Antonio Rodriguez v. Secretary, Florida Department of Corrections | 11-13273 | 1:10-cv-22692-PCH | NEW | 06-30-2014
Securities and Exchange Commission v. Joseph J. Monterosso, et al. | 13-10341 | 0:07-cv-61693-JAL | NEW | 06-30-2014
Timothy Finnerty v. Stiefel Laboratories, Inc., et al. | 12-13947 | 1:09-cv-21871-JLK | NEW | 06-30-2014
Timothy Finnerty v. Stiefel Laboratories, Inc., et al. | 12-15060 | 1:09-cv-21871-JLK | CON | 06-30-2014
Timothy Finnerty v. Stiefel Laboratories, Inc., et al. | 12-15642 | 1:09-cv-21871-JLK | CON | 06-30-2014
Jose Fernando Castillo v. U.S. Attorney General | 13-13445 | A093-022-401 | NEW | 06-27-2014
Richard J. Hubbard v. Clayton County School District, et al. | 13-12130 | 1:10-cv-00836-JOF | NEW | 06-27-2014
USA v. Lazaro Ramirez-Flores | 12-15602 | 8:12-cr-00169-EAK-MAP-1 | ORD | 06-27-2014
Cary Michael Lambrix v. Secretary, Florida Department of Corrections | 13-11917 | 2:13-cv-00226-JES-SPC | NEW | 06-26-2014
Harley N. Kane, et al v. Stewart Tilghman Fox & Bianchi PA, et al | 13-10560 | 9:12-cv-80750-KMM | NEW | 06-26-2014
Xilena M. Caceres v. McCalla Raymer, LLC | 13-12450 | 1:13-cv-20035-JLK | NEW | 06-26-2014
Mitchell A. Insignares v. Secretary, Florida Department of Corrections | 12-12378 | 1:11-cv-20858-MGC | NEW | 06-23-2014
USA v. Jorge Ramirez-Gonzalez | 13-13703 | 1:13-cr-00017-RWS-ECS-1 | NEW | 06-23-2014
USA v. Dylan Stanley | 13-10066 | 7:11-cr-00057-HL-TQL-1 | CON | 06-20-2014
USA v. Lee Dougherty | 12-16540 | 7:11-cr-00057-HL-TQL-2 | NEW | 06-20-2014
USA v. Ryan Dougherty | 13-10092 | 7:11-cr-00057-HL-TQL-3 | CON | 06-20-2014
Mississippi Valley Title Insurance Company, et al. v. J. Garrison Thompson | 12-16188 | 2:11-cv-00538-WS-C | CER | 06-19-2014
USA v. George D. Houser | 12-14302 | 4:10-cr-00012-HLM-WEJ-1 | NEW | 06-19-2014
David Johnson v. Keybank National Association | 13-14244 | 1:09-md-02036-JLK | NEW | 06-18-2014

Page: 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 >>